.. _how-to:

#############
How-to guides
#############

These guides presuppose some familiarity with django CMS. They cover some of
the same territory as the :doc:`/introduction/index`, but in more detail.


******
Set-up
******

.. toctree::
    :maxdepth: 1

    Install django CMS by hand <install>


************************
Using core functionality
************************

.. toctree::
    :maxdepth: 1

    Use placeholders outside the CMS <placeholders>
    Serve multiple languages <languages>
    Work with templates <templates>
    Manage caching <caching>
    Enable frontend editing for Page and Django models <frontend_models>
    Create sitemaps <sitemap>
    Manage Page Types <page_types>


**************************
Creating new functionality
**************************

.. toctree::
    :maxdepth: 1

    Create plugins <custom_plugins>
    Create apphooks <apphooks>
    Manage complex apphook configuration <namespaced_apphooks>
    Extend the Toolbar <toolbar>
    Customise navigation menus <menus>
    Create content creation wizards <wizards>
    Extend Page & Title models <extending_page_title>
    Test your extensions <testing>


************
Contributing
************

.. toctree::
    :maxdepth: 1

    Contribute a patch <contributing>
